@@ -226,6 +226,44 @@ impl super::Kubectl {
         }
     }
 
+    const MAX_RETRIES: u8 = u8::MAX;
+    pub async fn update<K>(
+        client: kube::api::Api<K>,
+        name: &str,
+        update_fn: impl FnMut(&mut K),
+    ) -> kube::Result<()>
+    where
+        K: std::fmt::Debug
+            + Clone
+            + serde::de::DeserializeOwned
+            + serde::Serialize
+            + kube::Resource,
+    {
+        Self::entry(
+            client,
+            name,
+            Self::MAX_RETRIES,
+            update_fn,
+            None::<fn() -> K>,
+        )
+        .await
+    }
+
+    pub async fn update_with_default<K>(
+        client: kube::api::Api<K>,
+        name: &str,
+        update_fn: impl FnMut(&mut K),
+        default: impl Fn() -> K,
+    ) -> kube::Result<()>
+    where
+        K: std::fmt::Debug
+            + Clone
+            + serde::de::DeserializeOwned
+            + serde::Serialize
+            + kube::Resource,
+    {
+        Self::entry(client, name, Self::MAX_RETRIES, update_fn, Some(default)).await
+    }
     /// try to `commit` changes (`update_fn`)
     /// to object `K`
     /// of name: `name`
@@ -313,11 +351,10 @@ impl super::Kubectl {
         name: &str,
         mut update_fn: impl FnMut(&mut BTreeMap<String, String>),
     ) -> kube::Result<()> {
-        const MAX_RETRY: u8 = 16;
         Self::entry(
             self.configmaps(None),
             name,
-            MAX_RETRY,
+            Self::MAX_RETRIES,
             |cm| update_fn(cm.data.get_or_insert_with(BTreeMap::default)),
             Some(|| corev1::ConfigMap::new(name)),
         )
